@@ -1,52 +1,52 @@
-from reamber.quaver.QuaMapObj import QuaMapObj
-from reamber.quaver.QuaMapObjMeta import QuaMapObjMode
-from reamber.osu.OsuMapObj import OsuMapObj
-from reamber.osu.OsuHitObj import OsuHitObj
-from reamber.osu.OsuHoldObj import OsuHoldObj
-from reamber.osu.OsuBpmObj import OsuBpmObj
-from reamber.osu.OsuSvObj import OsuSvObj
-from reamber.base.BpmObj import BpmObj
+from typing import List
 
+from reamber.base.Bpm import Bpm
+from reamber.osu.OsuBpm import OsuBpm
+from reamber.osu.OsuHit import OsuHit
+from reamber.osu.OsuHold import OsuHold
+from reamber.osu.OsuMap import OsuMap
+from reamber.osu.OsuSv import OsuSv
 from reamber.osu.lists.OsuBpmList import OsuBpmList
 from reamber.osu.lists.OsuNotePkg import OsuNotePkg
-from reamber.osu.lists.notes.OsuHoldList import OsuHoldList
-from reamber.osu.lists.notes.OsuHitList import OsuHitList
 from reamber.osu.lists.OsuSvList import OsuSvList
-from typing import List
+from reamber.osu.lists.notes.OsuHitList import OsuHitList
+from reamber.osu.lists.notes.OsuHoldList import OsuHoldList
+from reamber.quaver.QuaMap import QuaMap
+from reamber.quaver.QuaMapMeta import QuaMapMode
 
 
 class QuaToOsu:
     @staticmethod
-    def convert(qua: QuaMapObj) -> OsuMapObj:
+    def convert(qua: QuaMap) -> OsuMap:
         """ Converts a Quaver map to an osu map
 
         :param qua: Quaver map
         :return: Osu Map
         """
 
-        hits: List[OsuHitObj] = []
-        holds: List[OsuHoldObj] = []
+        hits: List[OsuHit] = []
+        holds: List[OsuHold] = []
 
         # Note Conversion
         for hit in qua.notes.hits():
-            hits.append(OsuHitObj(offset=hit.offset, column=hit.column))
+            hits.append(OsuHit(offset=hit.offset, column=hit.column))
         for hold in qua.notes.holds():
-            holds.append(OsuHoldObj(offset=hold.offset, column=hold.column, length=hold.length))
+            holds.append(OsuHold(offset=hold.offset, column=hold.column, _length=hold.length))
 
-        bpms: List[BpmObj] = []
-        svs: List[OsuSvObj] = []
+        bpms: List[Bpm] = []
+        svs: List[OsuSv] = []
         # Timing Point Conversion
         for bpm in qua.bpms:
-            bpms.append(OsuBpmObj(offset=bpm.offset, bpm=bpm.bpm))
+            bpms.append(OsuBpm(offset=bpm.offset, bpm=bpm.bpm))
 
         for sv in qua.svs:
-            svs.append(OsuSvObj(offset=sv.offset, multiplier=sv.multiplier))
+            svs.append(OsuSv(offset=sv.offset, multiplier=sv.multiplier))
 
         # Extract Metadata
-        osuMap = OsuMapObj(
+        osuMap = OsuMap(
             backgroundFileName=qua.backgroundFile,
             title=qua.title,
-            circleSize=QuaMapObjMode.keys(qua.mode),
+            circleSize=QuaMapMode.keys(qua.mode),
             titleUnicode=qua.title,
             artist=qua.artist,
             artistUnicode=qua.artist,
