@@ -1,11 +1,13 @@
 from __future__ import annotations
-from reamber.osu.lists.notes.OsuNoteList import OsuNoteList
-from reamber.osu.OsuHoldObj import OsuHoldObj
-from reamber.base.lists.notes.HoldList import HoldList
+
 from typing import List
 
+from reamber.base.lists.notes.HoldList import HoldList
+from reamber.osu.OsuHold import OsuHold
+from reamber.osu.lists.notes.OsuNoteList import OsuNoteList
 
-class OsuHoldList(List[OsuHoldObj], OsuNoteList, HoldList):
+
+class OsuHoldList(List[OsuHold], HoldList, OsuNoteList):
 
     def _upcast(self, objList: List = None) -> OsuHoldList:
         """ This is to facilitate inherited functions to work
@@ -15,5 +17,9 @@ class OsuHoldList(List[OsuHoldObj], OsuNoteList, HoldList):
         """
         return OsuHoldList(objList)
 
-    def data(self) -> List[OsuHoldObj]:
+    def multOffset(self, by: float, inplace:bool = False):
+        HoldList.multOffset(self, by=by, inplace=inplace)
+
+    def data(self) -> List[OsuHold]:
         return self
+
