@@ -1,16 +1,15 @@
 import unittest
+from reamber.osu.OsuMap import OsuMap
 from tests.test.RSC_PATHS import *
 
-from reamber.osu.OsuMapObj import OsuMapObj
-from reamber.algorithms.analysis.bpm.bpmBeatOffsets import bpmBeatOffsets
 
 class TestBpmBeatOffsets(unittest.TestCase):
 
     # @profile
     def test_osu(self):
-        m = OsuMapObj()
+        m = OsuMap()
         m.readFile(OSU_CARAVAN)
-        bpmBeatOffsets(m.bpms, 4, 10000)
+        m.bpms.snapOffsets(nths=4, lastOffset=10000)
 
 
 if __name__ == '__main__':
