@@ -1,8 +1,10 @@
 import unittest
-from tests.test.RSC_PATHS import *
 
 from reamber.algorithms.convert.OsuToQua import OsuToQua
-from reamber.osu.OsuMapObj import OsuMapObj
+from reamber.osu.OsuMap import OsuMap
+from tests.test.RSC_PATHS import *
+
+
 # import logging
 #
 # logging.basicConfig(filename="event.log", filemode="w+", level=logging.DEBUG)
@@ -13,7 +15,7 @@ class TestOsuToQua(unittest.TestCase):
     # @profile
     def test_osu1(self):
         # Complex BPM Points
-        osu = OsuMapObj()
+        osu = OsuMap()
         osu.readFile(OSU_CARAVAN)
 
         qua = OsuToQua.convert(osu)
@@ -22,7 +24,7 @@ class TestOsuToQua(unittest.TestCase):
     # @profile
     def test_osu2(self):
         # Stops
-        osu = OsuMapObj()
+        osu = OsuMap()
         osu.readFile(OSU_ESCAPES)
 
         qua = OsuToQua.convert(osu)
@@ -31,7 +33,7 @@ class TestOsuToQua(unittest.TestCase):
     # @profile
     def test_osu3(self):
         # Complex BPM
-        osu = OsuMapObj()
+        osu = OsuMap()
         osu.readFile(OSU_GRAVITY)
 
         qua = OsuToQua.convert(osu)
