@@ -1,8 +1,10 @@
 import unittest
-from tests.test.RSC_PATHS import *
 
 from reamber.algorithms.convert.OsuToSM import OsuToSM
-from reamber.osu.OsuMapObj import OsuMapObj
+from reamber.osu.OsuMap import OsuMap
+from tests.test.RSC_PATHS import *
+
+
 # import logging
 #
 # logging.basicConfig(filename="event.log", filemode="w+", level=logging.DEBUG)
@@ -13,7 +15,7 @@ class TestOsuToSM(unittest.TestCase):
     # # @profile
     # def test_osu1(self):
     #     # Complex BPM Points
-    #     osu = OsuMapObj()
+    #     osu = OsuMap()
     #     osu.readFile(OSU_CARAVAN)
     #
     #     sm = OsuToSM.convert(osu)
@@ -26,7 +28,7 @@ class TestOsuToSM(unittest.TestCase):
     # # @profile
     # def test_osu2(self):
     #     # Stops
-    #     osu = OsuMapObj()
+    #     osu = OsuMap()
     #     osu.readFile(OSU_ESCAPES)
     #
     #     sm = OsuToSM.convert(osu)
@@ -36,7 +38,7 @@ class TestOsuToSM(unittest.TestCase):
     # @profile
     def test_osu3(self):
         # Complex BPM
-        osu = OsuMapObj()
+        osu = OsuMap()
         osu.readFile(OSU_GRAVITY)
 
         sm = OsuToSM.convert(osu)
