@@ -1,8 +1,10 @@
 import unittest
-from tests.test.RSC_PATHS import *
 
 from reamber.algorithms.convert.QuaToSM import QuaToSM
-from reamber.quaver.QuaMapObj import QuaMapObj
+from reamber.quaver.QuaMap import QuaMap
+from tests.test.RSC_PATHS import *
+
+
 # import logging
 #
 # logging.basicConfig(filename="event.log", filemode="w+", level=logging.DEBUG)
@@ -13,7 +15,7 @@ class TestQuaToSm(unittest.TestCase):
     # @profile
     def test_qua1(self):
         # Complex BPM Points
-        qua = QuaMapObj()
+        qua = QuaMap()
         qua.readFile(QUA_NEURO_CLOUD)
 
         sm = QuaToSM.convert(qua)
