@@ -1,10 +1,9 @@
-import unittest
-from tests.test.RSC_PATHS import *
-
-from reamber.osu.OsuMapObj import OsuMapObj
-from reamber.algorithms.meta.hitSoundCopy import hitSoundCopy
-
 import logging
+import unittest
+
+from reamber.algorithms.mutate.hitSoundCopy import hitSoundCopy
+from reamber.osu.OsuMap import OsuMap
+from tests.test.RSC_PATHS import *
 
 logging.basicConfig(filename="event.log", filemode="w+", level=logging.DEBUG)
 
@@ -13,10 +12,10 @@ class TestHitsoundCopy(unittest.TestCase):
 
     # # @profile
     # def test_osu1(self):
-    #     mFrom = OsuMapObj()
+    #     mFrom = OsuMap()
     #     mFrom.readFile(OSU_AVENGER_HITSOUNDFILE)
     #
-    #     mTo = OsuMapObj()
+    #     mTo = OsuMap()
     #     mTo.readFile(OSU_AVENGER_HITSOUNDABLE)
     #
     #     mOut = hitSoundCopy(mFrom=mFrom, mTo=mTo)
@@ -25,10 +24,10 @@ class TestHitsoundCopy(unittest.TestCase):
 
     # @profile
     def test_osu2(self):
-        mFrom = OsuMapObj()
+        mFrom = OsuMap()
         mFrom.readFile(OSU_TRIBAL_TRIAL_MX)
 
-        mTo = OsuMapObj()
+        mTo = OsuMap()
         mTo.readFile(OSU_TRIBAL_TRIAL_EXH)
 
         mOut = hitSoundCopy(mFrom=mFrom, mTo=mTo)
